# OHP Pipeline

Cette librairie est écrite dans le but de fournir des méthodes simple pour la réduction d'image
obtenues à l'Observatoire de Haute Provence.

## Réduction basique d'images

### Création de Biais Maître

### Création de PLU Maître

### Reduction de Piles d'image

## Analyse des spectres obtenue au T152
